DATA_DIR = "/usr/local/share"
LIB_DIR = "/usr/local/lib"
VERSION = "0.16.0"
PACKAGE = "gnome-mag"
PYTHONDIR = "/usr/local/lib/python2.6/dist-packages"
